==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ReplicaSetListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ReplicaSetListFluent<A extends V1ReplicaSetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1ReplicaSet item);
    public A setToItems(int index,V1ReplicaSet item);
    public A addToItems(V1ReplicaSet... items);
    public A addAllToItems(Collection<V1ReplicaSet> items);
    public A removeFromItems(V1ReplicaSet... items);
    public A removeAllFromItems(Collection<V1ReplicaSet> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ReplicaSet> getItems();
    public List<V1ReplicaSet> buildItems();
    public V1ReplicaSet buildItem(int index);
    public V1ReplicaSet buildFirstItem();
    public V1ReplicaSet buildLastItem();
    public V1ReplicaSet buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ReplicaSetBuilder> predicate);
    public A withItems(List<V1ReplicaSet> items);
    public A withItems(V1ReplicaSet... items);
    public Boolean hasItems();
    public V1ReplicaSetListFluent.ItemsNested<A> addNewItem();
    public V1ReplicaSetListFluent.ItemsNested<A> addNewItemLike(V1ReplicaSet item);
    public V1ReplicaSetListFluent.ItemsNested<A> setNewItemLike(int index,V1ReplicaSet item);
    public V1ReplicaSetListFluent.ItemsNested<A> editItem(int index);
    public V1ReplicaSetListFluent.ItemsNested<A> editFirstItem();
    public V1ReplicaSetListFluent.ItemsNested<A> editLastItem();
    public V1ReplicaSetListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ReplicaSetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> withNewMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ReplicaSetListFluent.MetadataNested<A> editMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ReplicaSetFluent<V1ReplicaSetListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ReplicaSetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ReplicaSetListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1ReplicaSetListFluent<A extends V1ReplicaSetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1ReplicaSet item);
    public A setToItems(int index,V1ReplicaSet item);
    public A addToItems(V1ReplicaSet... items);
    public A addAllToItems(Collection<V1ReplicaSet> items);
    public A removeFromItems(V1ReplicaSet... items);
    public A removeAllFromItems(Collection<V1ReplicaSet> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ReplicaSet> getItems();
    public List<V1ReplicaSet> buildItems();
    public V1ReplicaSet buildItem(int index);
    public V1ReplicaSet buildFirstItem();
    public V1ReplicaSet buildLastItem();
    public V1ReplicaSet buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1ReplicaSetBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1ReplicaSetBuilder> predicate);
    public A withItems(List<V1ReplicaSet> items);
    public A withItems(V1ReplicaSet... items);
    public Boolean hasItems();
    public V1ReplicaSetListFluent.ItemsNested<A> addNewItem();
    public V1ReplicaSetListFluent.ItemsNested<A> addNewItemLike(V1ReplicaSet item);
    public V1ReplicaSetListFluent.ItemsNested<A> setNewItemLike(int index,V1ReplicaSet item);
    public V1ReplicaSetListFluent.ItemsNested<A> editItem(int index);
    public V1ReplicaSetListFluent.ItemsNested<A> editFirstItem();
    public V1ReplicaSetListFluent.ItemsNested<A> editLastItem();
    public V1ReplicaSetListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1ReplicaSetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> withNewMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1ReplicaSetListFluent.MetadataNested<A> editMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> editOrNewMetadata();
    public V1ReplicaSetListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ReplicaSetFluent<V1ReplicaSetListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1ReplicaSetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
